Rename btrfs_parse_early_options() to btrfs_parse_device_options(). As
btrfs_parse_early_options() parses the -o device options and scan the
device provided. So this rename specifies its action. Also the function
name is inline with btrfs_parse_subvol_options().
No functional changes.

Signed-off-by: Anand Jain <anand.j...@oracle.com>
---
 fs/btrfs/super.c | 14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)

diff --git a/fs/btrfs/super.c b/fs/btrfs/super.c
index 9d340f8d3457..9dc56d3eaa66 100644
--- a/fs/btrfs/super.c
+++ b/fs/btrfs/super.c
@@ -465,9 +465,9 @@ int btrfs_parse_options(struct btrfs_fs_info *info, char 
*options,
                case Opt_subvolrootid:
                case Opt_device:
                        /*
                         * These are parsed by btrfs_parse_subvol_options
                         * and btrfs_parse_early_options
                         * and can be happily ignored here.
                         */
                        break;
                case Opt_nodatasum:
@@ -883,8 +883,8 @@ int btrfs_parse_options(struct btrfs_fs_info *info, char 
*options,
  * All other options will be parsed on much later in the mount process and
  * only when we need to allocate a new super block.
  */
-static int btrfs_parse_early_options(const char *options, fmode_t flags,
-                                    void *holder)
+static int btrfs_parse_device_options(const char *options, fmode_t flags,
+                                     void *holder)
 {
        substring_t args[MAX_OPT_ARGS];
        char *device_name, *opts, *orig, *p;
@@ -951,7 +951,7 @@ static int btrfs_parse_subvol_options(const char *options, 
char **subvol_name,
 
        /*
         * strsep changes the string, duplicate it because
         * btrfs_parse_early_options gets called later
         */
        opts = kstrdup(options, GFP_KERNEL);
        if (!opts)
@@ -1558,7 +1558,7 @@ static struct dentry *btrfs_mount_root(struct 
file_system_type *fs_type,
        }
 
        mutex_lock(&uuid_mutex);
-       error = btrfs_parse_early_options(data, mode, fs_type);
+       error = btrfs_parse_device_options(data, mode, fs_type);
        if (error) {
                mutex_unlock(&uuid_mutex);
                goto error_fs_info;
@@ -465,9 +465,9 @@ int btrfs_parse_options(struct btrfs_fs_info *info, char 
                case Opt_device:
                        /*
-                        * These are parsed by btrfs_parse_subvol_options
-                        * and btrfs_parse_early_options
-                        * and can be happily ignored here.
+                        * These are parsed by btrfs_parse_subvol_options and
+                        * btrfs_parse_device_options and can be happily
+                        * ignored here.
                         */
                        break;
@@ -951,7 +951,7 @@ static int btrfs_parse_subvol_options(const char *options, 
        /*
         * strsep changes the string, duplicate it because
-        * btrfs_parse_early_options gets called later
+        * btrfs_parse_device_options gets called later
         */
        opts = kstrdup(options, GFP_KERNEL);
-- 
2.15.0

--
To unsubscribe from this list: send the line "unsubscribe linux-btrfs" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html

Reply via email to